@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,15 +15,15 @@
 
   MagickCore image profile methods.
 */
-#ifndef _MAGICKCORE_PROFILE_H
-#define _MAGICKCORE_PROFILE_H
+#ifndef MAGICKCORE_PROFILE_H
+#define MAGICKCORE_PROFILE_H
+
+#include "magick/string_.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-#include "magick/string_.h"
-
 typedef struct _ProfileInfo
 {
   char
